[![ReadTheDocs](https://img.shields.io/readthedocs/flowws-keras-experimental.svg?style=flat)](https://flowws-keras-experimental.readthedocs.io/en/latest/)

# Flowws Modules for Machine Learning Experiments with Keras

`flowws-keras-experimental` is a set of
[flowws](https://flowws.readthedocs.io) modules to train machine
learning models using tensorflow and keras. It contains basic modules
to perform common tasks such as loading data and specifying model
architectures.

## Installation

Install `flowws-keras-experimental` from PyPI:

```
pip install flowws-keras-experimental
```

Alternatively, install from source:

```
pip install git+https://github.com/klarh/flowws-keras-experimental.git#egg=flowws-keras-experimental
```

## API Documentation

Browse more detailed documentation
[online](https://flowws-keras-experimental.readthedocs.io) or build the sphinx
documentation from source:

```
git clone https://github.com/klarh/flowws-keras-experimental
cd flowws-keras-experimental/doc
pip install -r requirements.txt
make html
```
